@@ -1,6 +1,6 @@
 package MARC::Moose::Field::Control;
 {
-  $MARC::Moose::Field::Control::VERSION = '0.024';
+  $MARC::Moose::Field::Control::VERSION = '0.025';
 }
 # ABSTRACT: Control Marc field (tag < 010)
 
@@ -16,6 +16,17 @@ override 'as_formatted' => sub {
     join ' ', ( $self->tag, $self->value );
 };
 
+
+override 'clone' => sub {
+    my ($self, $tag) = @_;
+    my $field = MARC::Moose::Field::Control->new( tag => $self->tag );
+    $field->tag($tag) if $tag;
+    my $value = $self->value . '';
+    $field->value($value);
+    return $field;
+};
+
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -32,7 +43,7 @@ MARC::Moose::Field::Control - Control Marc field (tag < 010)
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 AUTHOR
 
